Install ModernGL
================

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. code-block:: sh

    $ pip install --upgrade ModernGL

This tutorial will also use ``numpy`` to generate data and ``Pillow`` to save the final image.

.. code-block:: sh

    $ pip install --upgrade numpy Pillow

Proceed to the :doc:`next step <context>`.
